---
title: <span class="badge object-type-scalar"></span> GramPerNormalCubicMeter
---
# <span class="badge object-type-scalar"></span> GramPerNormalCubicMeter

Concentration: gram per normal cubic meter (g/Nm³)

## Definition

```python
# Concentration: gram per normal cubic meter (g/Nm³)
GramPerNormalCubicMeter: typing.Literal["congNm3"] = "congNm3"
```
